x2py
====

[![PyPI version](https://badge.fury.io/py/x2py.svg)](https://badge.fury.io/py/x2py)

*x2py* is the Python port of [x2](https://github.com/jaykang920/x2) that works
with both Python 2 and 3.

Requirements
------------

Python 2.7+ or 3.3+

### Modules

* pycrypto (or pycryptodome) for x2py.transforms.block_cipher
* pytest to run unit tests

Installation
------------

### Installing through PyPI

```
pip install x2py
```
